@@ -19,6 +19,7 @@ def sign(secret, value):
     
     '''
     key = hashlib.sha1((secret).encode('utf-8')).digest()
-    signed = hmac.new(key, msg=str(value), digestmod=hashlib.sha1)
-    signature = b64_encode(signed.digest())
-    return str(signature)
+    signed = hmac.new(key, msg=value.encode('utf8'), digestmod=hashlib.sha1)
+    digest = signed.digest()
+    signature = b64_encode(digest)
+    return signature.decode('ascii')
